@@ -1,6 +1,8 @@
 #ifndef POLICYTYPE_H
 #define POLICYTYPE_H
 
+#include <QtGlobal>
+
 /*!
   \namespace Sailfish::PolicyTypes
   \internal
@@ -16,7 +18,7 @@ enum PolicyType {
     CameraEnabled,
     LocationSettingsEnabled,
     OsUpdatesEnabled,
-    SideLoadingSettingsEnabled,
+    SideLoadingSettingsEnabled Q_DECL_DEPRECATED,
     DeveloperModeSettingsEnabled,
     ApplicationInstallationEnabled,
     WlanToggleEnabled,
@@ -24,13 +26,13 @@ enum PolicyType {
     DeviceResetEnabled,
     ScreenshotEnabled,
     MobileNetworkSettingsEnabled,
-    UsbMassStorageEnabled,
+    UsbMassStorageEnabled Q_DECL_DEPRECATED,
     UsbDeveloperModeEnabled,
     UsbMtpEnabled,
-    UsbHostEnabled,
-    UsbConnectionSharingEnabled,
-    UsbDiagnosticModeEnabled,
-    UsbAdbEnabled,
+    UsbHostEnabled Q_DECL_DEPRECATED,
+    UsbConnectionSharingEnabled Q_DECL_DEPRECATED,
+    UsbDiagnosticModeEnabled Q_DECL_DEPRECATED,
+    UsbAdbEnabled Q_DECL_DEPRECATED,
     DateTimeSettingsEnabled,
     MicrophoneEnabled,
     FlightModeToggleEnabled,
@@ -44,6 +46,14 @@ enum PolicyType {
     BrowserEnabled,
     AccountCreationEnabled,
     BluetoothToggleEnabled,
+    SdMountEnabled,
+    UsbMountEnabled,
+    GlobalServicesSettingsEnabled,
+    VoiceCallEnabled,
+    SMSEnabled,
+    SimPinningSettingsEnabled,
+    SimSlotsSettingsEnabled,
+    DevelSuEnabled,
 };
 
 #ifdef  __cplusplus
